@@ -5,7 +5,7 @@ use strict;
 use vars qw(
     @ISA @EXPORT $VERSION
     $Headless $SortKeys $SingleQuote
-    $ImplicitTyping $ImplicitUnicode 
+    $ImplicitBinary $ImplicitTyping $ImplicitUnicode 
     $UseCode $LoadCode $DumpCode
     $DeparseObject
 );
@@ -13,7 +13,7 @@ use 5.00307;
 use Exporter;
 
 BEGIN {
-    $VERSION = '1.03';
+    $VERSION = '1.05';
     @EXPORT  = qw( Dump Load DumpFile LoadFile );
     @ISA     = qw( Exporter );
 
@@ -139,7 +139,7 @@ YAML::Syck - Fast, lightweight YAML loader and dumper
 
 =head1 VERSION
 
-This document describes version 1.03 of YAML::Syck, released February 16, 2008.
+This document describes version 1.04 of YAML::Syck, released February 17, 2008.
 
 =head1 SYNOPSIS
 
