@@ -2,12 +2,15 @@
 #include "perl.h"
 #include "XSUB.h"
 
-#define NEED_grok_oct
+#define NEED_eval_pv
 #define NEED_grok_hex
 #define NEED_grok_number
 #define NEED_grok_numeric_radix
+#define NEED_grok_oct
 #define NEED_newRV_noinc
-#define NEED_sv_2pv_nolen
+#define NEED_newSVpvn_share
+#define NEED_sv_2pv_flags
+
 #include "ppport.h"
 #include "ppport_math.h"
 #include "ppport_sort.h"
